@@ -15,7 +15,7 @@ test_that("caching improves performance", {
   
   temp_dir <- tempfile()
   dir.create(temp_dir)
-  options(nomisdata.cache_dir = temp_dir)
+  options(nomisdata.cache_dir = file.path(tempdir(), "nomisdata_test"))
   on.exit(unlink(temp_dir, recursive = TRUE))
   
   # First fetch (uncached)
@@ -31,4 +31,4 @@ test_that("caching improves performance", {
   # Note: Actual caching would need to be implemented in fetch_nomis
   # This test documents expected behavior
   expect_s3_class(data1, "tbl_df")
-})
\ No newline at end of file
+})
